pub struct InputTokensDetails {
pub cached_tokens: Option<i64>,
pub cache_write_tokens: Option<i64>,
}Expand description
How much of the input was served from Azure’s prompt cache. The only way to tell whether the prompt prefix is actually stable, since a perturbed prefix fails silently by costing more.
Fields
cached_tokens: Option<i64>cache_write_tokens: Option<i64>Trait Implementations
Sourceimpl Clone for InputTokensDetails
impl Clone for InputTokensDetails
Sourcefn clone(&self) -> InputTokensDetails
fn clone(&self) -> InputTokensDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputTokensDetails
impl Debug for InputTokensDetails
Sourceimpl Default for InputTokensDetails
impl Default for InputTokensDetails
Sourcefn default() -> InputTokensDetails
fn default() -> InputTokensDetails
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InputTokensDetails
impl<'de> Deserialize<'de> for InputTokensDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more