pub struct OutputTokensDetails {
pub reasoning_tokens: Option<i64>,
}Expand description
How much of the output was thinking, which is what moves when the reasoning context widens or narrows.
Fields
reasoning_tokens: Option<i64>Trait Implementations
Sourceimpl Clone for OutputTokensDetails
impl Clone for OutputTokensDetails
Sourcefn clone(&self) -> OutputTokensDetails
fn clone(&self) -> OutputTokensDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputTokensDetails
impl Debug for OutputTokensDetails
Sourceimpl Default for OutputTokensDetails
impl Default for OutputTokensDetails
Sourcefn default() -> OutputTokensDetails
fn default() -> OutputTokensDetails
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OutputTokensDetails
impl<'de> Deserialize<'de> for OutputTokensDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more